<?php
/**
 * @package WordPress
 * @subpackage Campoal
 */

// Require Merlin autoloader
require_once get_parent_theme_file_path( '/admin/merlin/vendor/autoload.php' );

// Require Merlin main class
require_once get_parent_theme_file_path( '/admin/merlin/class-merlin.php' );

if ( ! class_exists( 'Merlin' ) ) {
	return;
}

/**
 * Set directory locations, text strings, and settings.
 */
$wizard = new Merlin(

	$config = array(
		'directory'            => 'admin/merlin', // Location / directory where Merlin WP is placed in your theme.
		'merlin_url'           => 'campoal_wizard', // The wp-admin page slug where Merlin WP loads.
		'parent_slug'          => 'themes.php', // The wp-admin parent page slug for the admin menu item.
		'capability'           => 'manage_options', // The capability required for this menu to be displayed to the user.
		'child_action_btn_url' => 'https://codex.wordpress.org/child_themes', // URL for the 'child-action-link'.
		'dev_mode'             => true, // Enable development mode for testing.
		'license_step'         => false, // EDD license activation step.
		'license_required'     => false, // Require the license activation step.
		'license_help_url'     => '', // URL for the 'license-tooltip'.
		'edd_remote_api_url'   => '', // EDD_Theme_Updater_Admin remote_api_url.
		'edd_item_name'        => '', // EDD_Theme_Updater_Admin item_name.
		'edd_theme_slug'       => '', // EDD_Theme_Updater_Admin item_slug.
		'ready_big_button_url' => admin_url('options-general.php?page=conikal-license'), // Link for the big button on the ready step.
	),
	$strings = array(
		'admin-menu'               => esc_html__( 'Theme Setup', 'campoal' ),

		/* translators: 1: Title Tag 2: Theme Name 3: Closing Title Tag */
		'title%s%s%s%s'            => esc_html__( '%1$s%2$s Themes &lsaquo; Theme Setup: %3$s%4$s', 'campoal' ),
		'return-to-dashboard'      => esc_html__( 'Return to the dashboard', 'campoal' ),
		'ignore'                   => esc_html__( 'Disable this wizard', 'campoal' ),

		'btn-skip'                 => esc_html__( 'Skip', 'campoal' ),
		'btn-next'                 => esc_html__( 'Next', 'campoal' ),
		'btn-start'                => esc_html__( 'Start', 'campoal' ),
		'btn-no'                   => esc_html__( 'Cancel', 'campoal' ),
		'btn-plugins-install'      => esc_html__( 'Install', 'campoal' ),
		'btn-child-install'        => esc_html__( 'Install', 'campoal' ),
		'btn-content-install'      => esc_html__( 'Install', 'campoal' ),
		'btn-import'               => esc_html__( 'Import', 'campoal' ),
		'btn-license-activate'     => esc_html__( 'Activate', 'campoal' ),
		'btn-license-skip'         => esc_html__( 'Later', 'campoal' ),

		/* translators: Theme Name */
		'license-header%s'         => esc_html__( 'Activate %s', 'campoal' ),
		/* translators: Theme Name */
		'license-header-success%s' => esc_html__( '%s is Activated', 'campoal' ),
		/* translators: Theme Name */
		'license%s'                => esc_html__( 'Enter your license key to enable remote updates and theme support.', 'campoal' ),
		'license-label'            => esc_html__( 'License key', 'campoal' ),
		'license-success%s'        => esc_html__( 'The theme is already registered, so you can go to the next step!', 'campoal' ),
		'license-json-success%s'   => esc_html__( 'Your theme is activated! Remote updates and theme support are enabled.', 'campoal' ),
		'license-tooltip'          => esc_html__( 'Need help?', 'campoal' ),

		/* translators: Theme Name */
		'welcome-header%s'         => esc_html__( 'Welcome to %s', 'campoal' ),
		'welcome-header-success%s' => esc_html__( 'Hi. Welcome back', 'campoal' ),
		'welcome%s'                => esc_html__( 'This wizard will set up your theme, install plugins, and import content. It is optional & should take only a few minutes.', 'campoal' ),
		'welcome-success%s'        => esc_html__( 'You may have already run this theme setup wizard. If you would like to proceed anyway, click on the "Start" button below.', 'campoal' ),

		'child-header'             => esc_html__( 'Install Child Theme', 'campoal' ),
		'child-header-success'     => esc_html__( 'You\'re good to go!', 'campoal' ),
		'child'                    => esc_html__( 'Let\'s build & activate a child theme so you may easily make theme changes.', 'campoal' ),
		'child-success%s'          => esc_html__( 'Your child theme has already been installed and is now activated, if it wasn\'t already.', 'campoal' ),
		'child-action-link'        => esc_html__( 'Learn about child themes', 'campoal' ),
		'child-json-success%s'     => esc_html__( 'Awesome. Your child theme has already been installed and is now activated.', 'campoal' ),
		'child-json-already%s'     => esc_html__( 'Awesome. Your child theme has been created and is now activated.', 'campoal' ),

		'plugins-header'           => esc_html__( 'Install Plugins', 'campoal' ),
		'plugins-header-success'   => esc_html__( 'You\'re up to speed!', 'campoal' ),
		'plugins'                  => esc_html__( 'Let\'s install some essential WordPress plugins to get your site up to speed.', 'campoal' ),
		'plugins-success%s'        => esc_html__( 'The required WordPress plugins are all installed and up to date. Press "Next" to continue the setup wizard.', 'campoal' ),
		'plugins-action-link'      => esc_html__( 'Advanced', 'campoal' ),

		'import-header'            => esc_html__( 'Import Content', 'campoal' ),
		'import'                   => esc_html__( 'Let\'s import content to your website, to help you get familiar with the theme.', 'campoal' ),
		'import-action-link'       => esc_html__( 'Advanced', 'campoal' ),

		'ready-header'             => esc_html__( 'All done. Have fun!', 'campoal' ),

		/* translators: Theme Author */
		'ready%s'                  => esc_html__( 'Your theme has been all set up. Enjoy your new theme by %s.', 'campoal' ),
		'ready-action-link'        => esc_html__( 'Extras', 'campoal' ),
		'ready-big-button'         => esc_html__( 'Enter license key', 'campoal' ),
		'ready-link-1'             => sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://www.conikal.com/', esc_html__( 'Explore More Products', 'campoal' ) ),
		'ready-link-2'             => sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://www.conikal.com/support/', esc_html__( 'Get Theme Support', 'campoal' ) ),
		'ready-link-3'             => sprintf( '<a href="%1$s">%2$s</a>', admin_url( 'customize.php' ), esc_html__( 'Start Customizing', 'campoal' ) ),
	)
);
