<?php
/** 
 * @package WordPress
 * @subpackage Campoal
 */

/**
 * Add custom border css to enqueue style theme
 *
 * @since Campoal 1.9.9
 */
if( !function_exists('conikal_custom_border_css') ): 
    function conikal_custom_border_css() {
        global $campoal_options;

        // border radius
        $label_border_radius        = isset($campoal_options['conikal_label_border_radius_field']) ? $campoal_options['conikal_label_border_radius_field'] : '6px';
        $button_border_radius       = isset($campoal_options['conikal_button_border_radius_field']) ? $campoal_options['conikal_button_border_radius_field'] : '10px';
        $card_border_radius         = isset($campoal_options['conikal_card_border_radius_field']) ? $campoal_options['conikal_card_border_radius_field'] : '10px';
        $segment_border_radius      = isset($campoal_options['conikal_segment_border_radius_field']) ? $campoal_options['conikal_segment_border_radius_field'] : '12px';

        $custom_style = '';

        if ($label_border_radius != '') {
            $custom_style .= '
            .ui.label,
            .widget .tagcloud a, 
            .widget .wp-block-tag-cloud a, 
            p.wp-block-tag-cloud a, 
            .wc-block-grid__product-onsale, 
            .woocommerce ul.cart_list li img, 
            .ui.image.label {
                border-radius: ' . esc_attr( $label_border_radius ) . '; }';
        }

        if ($button_border_radius != '') {
            $custom_style .= 'button, 
            .ui.button:not(.circular), 
            .vc_btn1, 
            .vc_btn2, 
            .vc_btn3, 
            input[type="submit"], 
            .give_notices,
            .give_success,
            .give_warning,
            .wpas-alert,
            .wpas-btn-default,
            .ui.basic.button:not(.circular), 
            .ui.basic.buttons .button:not(.circular),
            .ui.vertical.buttons .button:only-child,
            .box-upload,
            .ui.message,
            .ui.menu,
            .ui.secondary.menu:not(.pointing) > .right.menu > .item,
            .ui.secondary.menu:not(.pointing) > .left.menu > .item,
            .ui.secondary.menu:not(.pointing) > .ui.container > .right.menu > .item,
            .ui.secondary.menu:not(.pointing) > .ui.container > .left.menu > .item,
            .ui.secondary.menu:not(.pointing) .dropdown.item > .menu, 
            .ui.text.menu .dropdown.item > .menu,
            .wedocs-single-wrap .wedocs-sidebar ul.doc-nav-list > li.current_page_parent > a, 
            .wedocs-single-wrap .wedocs-sidebar ul.doc-nav-list > li.current_page_item > a, 
            .wedocs-single-wrap .wedocs-sidebar ul.doc-nav-list > li.current_page_ancestor > a,
            .radio-flex .radio-container .radio-options,
            .radio-flex .radio-container .radio-options label,
            .stv-radio-buttons-wrapper,
            .wpcf7 form .wpcf7-response-output, 
            input.wpcf7-form-control.wpcf7-submit, 
            .wp-block-search__button, 
            .wc-credit-card-form .wc-stripe-elements-field, 
            .wc-credit-card-form .wc-stripe-iban-element-field, 
            .wc-payment-form .wc-stripe-elements-field, 
            .wc-payment-form .wc-stripe-iban-element-field,
            .widget_calendar tbody tr td#today, 
            .give-btn, 
            .page-links a, 
            .page-links > span, 
            .woocommerce-error, 
            .woocommerce-info, 
            .woocommerce-message,
            .woocommerce #respond input#submit, 
            .woocommerce a.button, 
            .woocommerce button.button, 
            .woocommerce input.button { 
                border-radius: ' . esc_attr( $button_border_radius ) . '; }
            input, textarea, select,
            .wp-block-search__input, 
            .ui.active.empty.selection.dropdown, 
            .ui.dropdown .menu, 
            .ui.dropdown .menu .menu, 
            .ui.pointing.dropdown>.menu,
            .ui.selection.dropdown>.menu,
            .ui.form select, 
            .ui.selection.dropdown, 
            .ui.steps, 
            .ui.form textarea, 
            .ui.progress .bar,
            .ui.active.progress .bar::after, 
            [data-tooltip]:after,
            .ui.popup,
            .feature-navigation.slick-initialized.slick-slider .slick-slide img.ui.fluid.image,
            input:focus, 
            textarea:focus, 
            select:focus, 
            .ui.form textarea:focus, 
            .ui.form input:not([type]):focus, 
            .ui.form input[type=date]:focus, 
            .ui.form input[type=datetime-local]:focus, 
            .ui.form input[type=email]:focus, 
            .ui.form input[type=file]:focus, 
            .ui.form input[type=number]:focus, 
            .ui.form input[type=password]:focus, 
            .ui.form input[type=search]:focus, 
            .ui.form input[type=tel]:focus, 
            .ui.form input[type=text]:focus, 
            .ui.form input[type=time]:focus, 
            .ui.form input[type=url]:focus, 
            .ui[class*="left action"].input>input:focus, 
            .ui[class*="right action"].input>input:focus, 
            .ui.selection.dropdown:focus, 
            input:focus.wpcf7-form-control.wpcf7-text, 
            textarea:focus.wpcf7-form-control.wpcf7-textarea,
            .ui.input > input, 
            .ui.form input:not([type]), 
            .ui.form input[type=date], 
            .ui.form input[type=datetime-local], 
            .ui.form input[type=email], 
            .ui.form input[type=file], 
            .ui.form input[type=number], 
            .ui.form input[type=password], 
            .ui.form input[type=search], 
            .ui.form input[type=tel], 
            .ui.form input[type=text], 
            .ui.form input[type=time], 
            .ui.form input[type=url],
            #give-recurring-form .form-row input[type=text],
            #give-recurring-form .form-row input[type=tel],
            #give-recurring-form .form-row input[type=email],
            #give-recurring-form .form-row input[type=password],
            #give-recurring-form .form-row input[type=url],
            #give-recurring-form .form-row select,
            #give-recurring-form .form-row textarea,
            form.give-form .form-row input[type=text],
            form.give-form .form-row input[type=tel],
            form.give-form .form-row input[type=email],
            form.give-form .form-row input[type=password],
            form.give-form .form-row input[type=url],
            form.give-form .form-row select,
            form.give-form .form-row textarea,
            form[id*=give-form] .form-row input[type=text],
            form[id*=give-form] .form-row input[type=tel],
            form[id*=give-form] .form-row input[type=email],
            form[id*=give-form] .form-row input[type=password],
            form[id*=give-form] .form-row input[type=url],
            form[id*=give-form] .form-row select,
            form[id*=give-form] .form-row textarea,
            form[id*=give-form] .give-donation-amount #give-amount, 
            form[id*=give-form] .give-donation-amount #give-amount-text, 
            form[id*=give-form] #give-final-total-wrap .give-final-total-amount,
            input.wpcf7-form-control.wpcf7-text, 
            textarea.wpcf7-form-control.wpcf7-textarea,
            .woocommerce form .form-row input.input-text, 
            .woocommerce form .form-row textarea,
            .woocommerce .select2-container--default .select2-selection--single,
            .form-row .give-stripe-cc-field, 
            .wc-credit-card-form .wc-stripe-elements-field, 
            .wc-credit-card-form .wc-stripe-iban-element-field, 
            .wc-payment-form .wc-stripe-elements-field, 
            .wc-payment-form .wc-stripe-iban-element-field, 
            .wc-block-grid__products .wc-block-grid__product-image img, 
            .wc-block-components-price-slider__controls 
            .wc-block-components-price-slider__amount, 
            .ui.pointing.upward.dropdown .menu, 
            .ui.top.pointing.upward.dropdown .menu,
            .select2-dropdown { 
                border-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.secondary.vertical.menu:not(.pointing)>.item,
            .ui.dropdown .menu .menu, 
            .ui.secondary.menu:not(.pointing) > .item.user-menu,
            .ui.secondary.menu:not(.pointing) > .item.searchBtn,
            .ui.secondary.menu:not(.pointing) > .item, 
            .ui.secondary.menu:not(.pointing) > .active.item,
            .ui.secondary.menu:not(.pointing) > .right.menu > .item,
            .ui.secondary.menu:not(.pointing) > .ui.container > .item.user-menu,
            .ui.secondary.menu:not(.pointing) > .ui.container > .item.searchBtn,
            .ui.secondary.menu:not(.pointing) > .ui.container > .item, 
            .ui.secondary.menu:not(.pointing) > .ui.container > .active.item,
            .ui.secondary.menu:not(.pointing) > .ui.container > .right.menu > .item,
            .ui.secondary.menu:not(.pointing) > .ui.container .item.user-menu
            .ui.dropdown .menu .left.menu, .ui.dropdown>.left.menu .menu,
            .header-menu .ui.dropdown.user-menu .menu, .header-menu .ui.dropdown.user-menu .menu,
            .wp-2fa-configuration-form .button.button-primary,
            .wp2fa-modal .modal__content .modal__btn, 
            .wp2fa-modal .modal__content .wp2fa-setup-actions .button,
            .wp-2fa-configuration-form .button,
            .flaggedc-button.flaggedc-submit-button.flaggedc-button-style-theme,
            .flaggedc-alert-box-success,
            .pac-container, 
            .wedocs-alert.wedocs-alert-danger,
            .wedocs-alert.wedocs-alert-success,
            .gallery .gallery-item img, 
            .widget_media_image img, 
            .woocommerce ul.product_list_widget li img, 
            .ui.floating.dropdown>.menu {
                border-radius: ' . esc_attr( $button_border_radius ) . ' !important; }
            
            .ui.attached:not(.vertical).top.actions,
            .widget_calendar caption, 
            .ui.vertical.buttons .button:first-child {
                border-bottom-left-radius: 0 !important;
                border-bottom-right-radius: 0 !important;
                border-top-left-radius: ' . esc_attr( $button_border_radius ) . ';
                border-top-right-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.modal > :last-child,
            .ui.attached:not(.vertical):not(.top).actions,
            .ui.vertical.buttons .button:last-child {
                border-top-left-radius: 0;
                border-top-right-radius: 0;
                border-bottom-left-radius: ' . esc_attr( $button_border_radius ) . ';
                border-bottom-right-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.modal > :first-child:not(.icon),
            .ui.modal > .header, 
            .ui.menu:not(.pointing, .secondary) .item:first-child, 
            .ui.menu.fixed .item:first-child, 
            .editor-toolbar {
                border-bottom-left-radius: 0 !important;
                border-bottom-right-radius: 0 !important;
                border-top-left-radius: ' . esc_attr( $button_border_radius ) . ' !important;
                border-top-right-radius: ' . esc_attr( $button_border_radius ) . ' !important; }
            .ui.menu:not(.pointing, .secondary) .item:last-child, 
            .ui.menu.fixed .item:last-child, 
            .CodeMirror,
            .widget_calendar table {
                border-top-left-radius: 0;
                border-top-right-radius: 0;
                border-bottom-left-radius: ' . esc_attr( $button_border_radius ) . ' !important;
                border-bottom-right-radius: ' . esc_attr( $button_border_radius ) . ' !important; }    ';
        }

        if ($segment_border_radius != '') {
            $custom_style .= '
            table,
            .ui.segment:not(.vertical, .attached), 
            .ui.horizontal.segments,
            .ui.segments:not(.horizontal) > .segment:only-child {
                border-radius: ' . esc_attr( $segment_border_radius ) . '; }

            .ui.loading.segment:before,
            .ui.table,
            .ui.modal,
            .ui.modal>.content, 
            .give-modal .mfp-content, 
            .modal__container, 
            .wedocs-contact-modal, 
            .flaggedc-form-modal, 
            .wp-block-latest-posts.wp-block-latest-posts__list, 
            .menu-testing-menu-container > ul, 
            ul.wp-block, 
            .wp-block-categories-list, 
            .wp-block-archives-list, 
            .wp-block > ul:not(.product_list_widget, .wp-block-rss), 
            .wp-block > div > ul:not(.product_list_widget, .wp-block-rss), 
            .wp-block > div > div > ul:not(.product_list_widget, .wp-block-rss), 
            .widget > ul:not(.product_list_widget, .wp-block-rss), 
            .widget > div > ul:not(.product_list_widget, .wp-block-rss), 
            .widget > div > div > ul:not(.product_list_widget, .wp-block-rss), 
            .widget_recent_comments ol li, 
            .widget_rss ul li, 
            .wp-block-rss li, 
            .wp-block-latest-comments li, 
            .widget > ul.product_list_widget li, 
            table.give-table,
            .post-navigation,
            .wpas-uploader-dropzone,
            .classic-post-card .behind-thumbnail, 
            .woocommerce .woocommerce-customer-details address,
            .wedocs-single-wrap .wedocs-single-content article .entry-content img,
            .woocommerce div.product div.images .woocommerce-product-gallery__image, 
            .woocommerce div.product div.images .flex-control-thumbs li img, 
            #isDesc {
                border-radius: ' . esc_attr( $segment_border_radius ) . ' !important; }

            table thead tr:first-child>th:last-child,
            .ui.table thead tr:first-child>th:last-child {
                border-top-right-radius: ' . esc_attr( $segment_border_radius ) . '; }
            
            table thead tr:first-child>th:first-child,
            .ui.table thead tr:first-child>th:first-child {
                border-top-left-radius: ' . esc_attr( $segment_border_radius ) . '; }

            table tbody tr:last-child>td:first-child,
            .ui.table tfoot tr>th:first-child {
                border-radius: 0 0 0 ' . esc_attr( $segment_border_radius ) . '; }
            
            table tbody tr:last-child>td:last-child,
            .ui.table tfoot tr>th:last-child {
                border-radius: 0 0 ' . esc_attr( $segment_border_radius ) . ' 0; }

            .ui.segments:not(.horizontal) > .segment:first-child {
                border-radius: ' . esc_attr( $segment_border_radius ) . ' ' . esc_attr( $segment_border_radius ) . ' 0 0 !important; }
                
            .ui[class *="top attached"].segment,
            .ui.attached.message,
            .ui.search>.results>:first-child,
            .ui[class *="top attached"].table {
                border-radius: ' . esc_attr( $segment_border_radius ) . ' ' . esc_attr( $segment_border_radius ) . ' 0 0 !important; }
            
            .ui.segments:not(.horizontal) > .segment:last-child {
                border-radius: 0 0 ' . esc_attr( $segment_border_radius ) . ' ' . esc_attr( $segment_border_radius ) . ' !important; }

            .ui.segment[class *="bottom attached"],
            .ui.bottom.attached.message,
            .ui.search>.results>:last-child,
            .ui[class *="bottom attached"].table {
                border-radius: 0 0 ' . esc_attr( $segment_border_radius ) . ' ' . esc_attr( $segment_border_radius ) . ' !important; }';
        }

        if ($card_border_radius != '') {
            $custom_style .= '
            .ui.card, .ui.cards > .card,
            .ui.card > :only-child, 
            .ui.cards > .card > :only-child,
            .ui.styled.accordion, 
            .ui.styled.accordion .accordion,
            .ui.search > .results,
            .ui.toast,
            .ui.toast-container .toast-box,
            .topic-card.snip,
            .petition-list-card .dimmer, 
            .petition-list-card .petition-thumbnail img,
            .timeline > li > .timeline-panel,
            #add_payment_method #payment div.payment_box, 
            .woocommerce-cart #payment div.payment_box, 
            .woocommerce-checkout #payment div.payment_box, 
            .wc-block-grid__product.wc-block-grid__product, 
            .single-post-simple .feature-image, 
            .ui.embed, 
            .ui.rounded.image, 
            .ui.rounded.image>*, 
            .ui.rounded.images .image, 
            .ui.rounded.images .image>* {
                border-radius: ' . esc_attr( $card_border_radius ) . ' !important; }
            .ui.card > :first-child, .ui.cards > .card > :first-child,
            .ui.bottom.nag, .ui.bottom.nags,
            .ui.bottom.nags .nag:last-child {
                border-radius: ' . esc_attr( $card_border_radius ) . ' ' . esc_attr( $card_border_radius ) . ' 0 0 !important; }
            .ui.card>.image, .ui.cards>.card>.image,
            .petition-card .petition-thumbnail img,
            .petition-card .ui.dimmer, 
            .product-category img {
                border-top-left-radius: ' . esc_attr( $segment_border_radius ) . ' !important;
                border-top-right-radius: ' . esc_attr( $segment_border_radius ) . ' !important; }
            .ui.card>.content, .ui.cards>.card>.content,
            .ui.card>.extra, .ui.cards>.card>.extra,
            .ui.card > :last-child, 
            .ui.cards > .card > :last-child,
            .ui.nag,
            .ui.nags .nag:last-child {
                border-radius: 0 0 ' . esc_attr( $card_border_radius ) . ' ' . esc_attr( $card_border_radius ) . ' !important;
            }';
        
        }

        // Right to Left
        if ( !is_rtl() ) {
            $custom_style .= '
            .increase-goal-selection > .ui.dropdown.selection:focus {
                border-bottom-left-radius: 0 !important; }
            .ui.upward.dropdown>.menu, 
            .ui[class *="top attached"].buttons { 
                border-radius: ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0 0; }
            .ui[class *="top attached"].buttons, 
            .ui[class *="top attached"].buttons .button:last-child,
            .ui[class *="right attached"].buttons .button:first-child { 
                border-radius: ' . esc_attr( $button_border_radius ) . ' 0 0 0; }
            .ui[class *="top attached"].buttons .button:last-child,
            .ui[class *="left attached"].buttons .button:first-child,
            .ui.labeled.input .corner.label,
            .ui[class *="top attached"].buttons .button:last-child { 
                border-radius: 0 ' . esc_attr( $button_border_radius ) . ' 0 0; }
            .ui[class *="bottom attached"].buttons,
            .ui[class *="tablet stackable"].steps .step:last-child,
            .ui[class *="bottom attached"].menu,
            .ui.upward.selection.dropdown.visible { 
                border-radius: 0 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' !important; }
            .ui[class *="bottom attached"].buttons .button:first-child, 
            .ui[class *="right attached"].buttons .button:last-child { 
                border-radius: 0 0 0 ' . esc_attr( $button_border_radius ) . '; }
            .ui[class *="bottom attached"].buttons .button:last-child, 
            .ui[class *="left attached"].buttons .button:last-child { 
                border-radius: 0 0 ' . esc_attr( $button_border_radius ) . ' 0; }
            .ui.action.input:not([class*="left action"]) > .button:last-child, 
            .ui.action.input:not([class*="left action"]) > .buttons:last-child>.button, 
            .ui.action.input:not([class*="left action"]) > .dropdown:last-child, 
            .ui[class *="left attached"].buttons,
            .ui.tag.label, .ui.tag.labels .label,
            .ui.ribbon.label { 
                border-radius: 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0 !important; }
            .increase-goal-selection > .ui.dropdown.selection,
            .ui[class *="right attached"].buttons, 
            .ui[class *="left icon"].input > i.icon, 
            .ui[class *="right ribbon"].label { 
                border-radius: ' . esc_attr( $button_border_radius ) . ' 0 0 ' . esc_attr( $button_border_radius ) . ' !important; }
            .ui.buttons .button:first-child,
            .ui.vertical.attached.left.actions,
            .ui.labeled.icon.buttons .button:first-child > .icon,
            form[id*=give-form] .give-donation-amount .give-currency-symbol.give-currency-position-before, 
            form[id*=give-form] #give-final-total-wrap .give-donation-total-label {
                border-top-left-radius: ' . esc_attr( $button_border_radius ) . ';
                border-bottom-left-radius: ' . esc_attr( $button_border_radius ) . ';
                border-top-right-radius: 0;
                border-bottom-right-radius: 0; }
            .ui.buttons .button:last-child,
            .ui.vertical.attached:not(.left).actions,
            .ui.vertical.attached.left.message.message.message,
            .ui.labeled.icon.buttons .button:last-child > .icon {
                border-top-right-radius: ' . esc_attr( $button_border_radius ) . ';
                border-bottom-right-radius: ' . esc_attr( $button_border_radius ) . ';
                border-top-left-radius: 0;
                border-bottom-left-radius: 0; }
            .ui.attached:not(.vertical).top.actions .button:first-child,
            .ui.vertical.labeled.icon.buttons .button:first-child > .icon {
                border-top-left-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.attached:not(.vertical).top.actions .button:last-child {
                border-top-right-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.vertical.attached:not(.left).message,
            .ui.attached:not(.vertical):not(.top).actions .button:first-child,
            .ui.vertical.labeled.icon.buttons .button:last-child > .icon {
                border-bottom-left-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.attached:not(.vertical):not(.top).actions .button:last-child {
                border-bottom-right-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.selection.dropdown .menu,
            .ui.upward.selection.dropdown.visible {
                border-radius: 0 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . '; }
            .ui.upward.selection.dropdown .menu {
                border-radius: ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0 0; }
            .ui.steps .step:last-child {
                border-radius: 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0; }
            .ui.steps .step:first-child,
            .ui[class*="left action"].input>.button:first-child, .ui[class*="left action"].input>.buttons:first-child>.button, .ui[class*="left action"].input>.dropdown:first-child {
                border-radius: ' . esc_attr( $button_border_radius ) . ' 0 0 ' . esc_attr( $button_border_radius ) . '; }
            @media only screen and (min-width: 768px) {
                .list-post-card .list-post-thumbnail, 
                .list-post-card .list-post-thumbnail img,
                .list-post-card .list-post-thumbnail .ui.dimmer,
                .feature-card .featured-image {
                    border-top-left-radius: ' . esc_attr( $segment_border_radius ) . ' !important;
                    border-bottom-left-radius: ' . esc_attr( $segment_border_radius ) . ' !important; }
            }
                
            @media only screen and (max-width: 767px) and (min-width: 320px) {
                .list-post-card .list-post-thumbnail, 
                .list-post-card .list-post-thumbnail img,
                .list-post-card .list-post-thumbnail .ui.dimmer,
                .feature-card .featured-image {
                    border-top-left-radius: ' . esc_attr( $segment_border_radius ) . ' !important;
                    border-top-right-radius: ' . esc_attr( $segment_border_radius ) . ' !important; }
            }';
        } else {
            $custom_style .= '
            .increase-goal-selection > .ui.dropdown.selection:focus {
                border-bottom-right-radius: 0 !important; }
            .ui.upward.dropdown>.menu, 
            .ui[class *="top attached"].buttons { 
                border-radius: ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0 0; }
            .ui[class *="top attached"].buttons, 
            .ui[class *="top attached"].buttons .button:last-child,
            .ui[class *="right attached"].buttons .button:first-child { 
                border-radius: ' . esc_attr( $button_border_radius ) . ' 0 0 0; }
            .ui[class *="top attached"].buttons .button:last-child,
            .ui[class *="left attached"].buttons .button:first-child,
            .ui.labeled.input .corner.label,
            .ui[class *="top attached"].buttons .button:last-child { 
                border-radius: 0 ' . esc_attr( $button_border_radius ) . ' 0 0; }
            .ui[class *="bottom attached"].buttons,
            .ui[class *="tablet stackable"].steps .step:last-child,
            .ui[class *="bottom attached"].menu,
            .ui.upward.selection.dropdown.visible { 
                border-radius: 0 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' !important; }
            .ui[class *="bottom attached"].buttons .button:first-child, 
            .ui[class *="right attached"].buttons .button:last-child { 
                border-radius: 0 0 0 ' . esc_attr( $button_border_radius ) . '; }
            .ui[class *="bottom attached"].buttons .button:last-child, 
            .ui[class *="left attached"].buttons .button:last-child { 
                border-radius: 0 0 ' . esc_attr( $button_border_radius ) . ' 0; }
            .ui.action.input:not([class*="left action"]) > .button:last-child, 
            .ui.action.input:not([class*="left action"]) > .buttons:last-child>.button, 
            .ui.action.input:not([class*="left action"]) > .dropdown:last-child, 
            .ui[class *="left attached"].buttons,
            .ui.tag.label, .ui.tag.labels .label,
            .ui.ribbon.label { 
                border-radius: ' . esc_attr( $button_border_radius ) . ' 0 0 ' . esc_attr( $button_border_radius ) . ' !important; }
            .increase-goal-selection > .ui.dropdown.selection,
            .ui[class *="right attached"].buttons, 
            .ui[class *="left icon"].input > i.icon, 
            .ui[class *="right ribbon"].label { 
                border-radius: 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0 !important; }
            .ui.buttons .button:first-child,
            .ui.vertical.attached.left.actions,
            .ui.labeled.icon.buttons .button:first-child > .icon,
            form[id*=give-form] .give-donation-amount .give-currency-symbol.give-currency-position-before, 
            form[id*=give-form] #give-final-total-wrap .give-donation-total-label {
                border-top-right-radius: ' . esc_attr( $button_border_radius ) . ';
                border-bottom-right-radius: ' . esc_attr( $button_border_radius ) . ';
                border-top-left-radius: 0;
                border-bottom-left-radius: 0; }
            .ui.buttons .button:last-child,
            .ui.vertical.attached:not(.left).actions,
            .ui.vertical.attached.left.message.message.message,
            .ui.labeled.icon.buttons .button:last-child > .icon {
                border-top-left-radius: ' . esc_attr( $button_border_radius ) . ';
                border-bottom-left-radius: ' . esc_attr( $button_border_radius ) . ';
                border-top-right-radius: 0;
                border-bottom-right-radius: 0; }
            .ui.attached:not(.vertical).top.actions .button:first-child,
            .ui.vertical.labeled.icon.buttons .button:first-child > .icon {
                border-top-right-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.attached:not(.vertical).top.actions .button:last-child {
                border-top-left-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.vertical.attached:not(.left).message,
            .ui.attached:not(.vertical):not(.top).actions .button:first-child,
            .ui.vertical.labeled.icon.buttons .button:last-child > .icon {
                border-bottom-right-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.attached:not(.vertical):not(.top).actions .button:last-child {
                border-bottom-left-radius: ' . esc_attr( $button_border_radius ) . '; }
            .ui.selection.dropdown .menu,
            .ui.upward.selection.dropdown.visible {
                border-radius: 0 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . '; }
            .ui.upward.selection.dropdown .menu {
                border-radius: ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0 0; }
            .ui.steps .step:last-child {
                border-radius: ' . esc_attr( $button_border_radius ) . ' 0 0 ' . esc_attr( $button_border_radius ) . '; }
            .ui.steps .step:first-child,
            .ui[class*="left action"].input>.button:first-child, .ui[class*="left action"].input>.buttons:first-child>.button, .ui[class*="left action"].input>.dropdown:first-child {
                border-radius: 0 ' . esc_attr( $button_border_radius ) . ' ' . esc_attr( $button_border_radius ) . ' 0; }
            @media only screen and (min-width: 768px) {
                .list-post-card .list-post-thumbnail, 
                .list-post-card .list-post-thumbnail img,
                .list-post-card .list-post-thumbnail .ui.dimmer,
                .feature-card .featured-image {
                    border-top-right-radius: ' . esc_attr( $segment_border_radius ) . ' !important;
                    border-bottom-right-radius: ' . esc_attr( $segment_border_radius ) . ' !important; }
            }
                
            @media only screen and (max-width: 767px) and (min-width: 320px) {
                .list-post-card .list-post-thumbnail, 
                .list-post-card .list-post-thumbnail img,
                .list-post-card .list-post-thumbnail .ui.dimmer,
                .feature-card .featured-image {
                    border-top-right-radius: ' . esc_attr( $segment_border_radius ) . ' !important;
                    border-top-left-radius: ' . esc_attr( $segment_border_radius ) . ' !important; }
            }';
        }
        
        
        return $custom_style;
    }
endif;