<?php
/**
 * @package WordPress
 * @subpackage Campoal
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

?>

<div class="ui raised padded segment">
	<table class="ui very basic single line table">
		<tbody class="boxed boxed--border cart-total <?php if ( WC()->customer->has_calculated_shipping() ) echo 'calculated_shipping'; ?>">
				<?php do_action( 'woocommerce_before_cart_totals' ); ?>
				
				<tr class="right aligned">
					<td>
						<?php esc_html_e('Cart Subtotal:', 'campoal'); ?>
					</td>
					<td>
						<?php wc_cart_totals_subtotal_html(); ?>
					</td>
				</tr>
				
				<?php foreach ( WC()->cart->get_coupons() as $code => $coupon ) : ?>
					<tr class="right aligned cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
						<td>
							<?php wc_cart_totals_coupon_label( $coupon ); ?>
						</td>
						<td>
							<?php wc_cart_totals_coupon_html( $coupon ); ?>
						</td>
					</tr>
				<?php endforeach; ?>
				

				<?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>
				
					<?php do_action( 'woocommerce_cart_totals_before_shipping' ); ?>
		
					<?php wc_cart_totals_shipping_html(); ?>
		
					<?php do_action( 'woocommerce_cart_totals_after_shipping' ); ?>
		
				<?php elseif ( WC()->cart->needs_shipping() && 'yes' === get_option( 'woocommerce_enable_shipping_calc' ) ) : ?>
		
					<tr class="right aligned shipping">
						<td><?php esc_html_e( 'Shipping', 'campoal' ); ?></td>
						<td data-title="<?php esc_attr_e( 'Shipping', 'campoal' ); ?>"><?php woocommerce_shipping_calculator(); ?></td>
					</tr>
		
				<?php endif; ?>
		
				<?php foreach ( WC()->cart->get_fees() as $fee ) : ?>
					<tr class="right aligned">
						<td>
							<?php echo esc_html( $fee->name ); ?>
						</td>
						<td>
							<?php wc_cart_totals_fee_html( $fee ); ?>
						</td>
					</tr>
				<?php endforeach; ?>
		
				<?php if ( wc_tax_enabled() && 'excl' === WC()->cart->tax_display_cart ) :
					$taxable_address = WC()->customer->get_taxable_address();
					$estimated_text  = WC()->customer->is_customer_outside_base() && ! WC()->customer->has_calculated_shipping()
							? sprintf( ' <small>(' . esc_html__( 'estimated for %s', 'campoal' ) . ')</small>', WC()->countries->estimated_for_prefix( $taxable_address[0] ) . WC()->countries->countries[ $taxable_address[0] ] )
							: '';
		
					if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) : ?>
						<?php foreach ( WC()->cart->get_tax_totals() as $code => $tax ) : ?>
							<tr class="right aligned tax-rate tax-rate-<?php echo sanitize_title( $code ); ?>">
								<td>
									<?php echo esc_html( $tax->label ) . $estimated_text; ?>
								</td>
								<td>
									<?php echo wp_kses_post( $tax->formatted_amount ); ?>
								</td>
							</tr>
						<?php endforeach; ?>
					<?php else : ?>
						<tr class="right aligned tax-rate tax-rate-<?php echo sanitize_title( $code ); ?>">
							<td>
								<?php echo esc_html( WC()->countries->tax_or_vat() ) . $estimated_text; ?>
							</td>
							<td>
								<?php wc_cart_totals_taxes_total_html(); ?>
							</td>
						</tr>
					<?php endif; ?>
				<?php endif; ?>

				<?php do_action( 'woocommerce_cart_totals_before_order_total' ); ?>
				
				<tfoot>	
					<tr class="right aligned">
						<th>
							<?php esc_html_e('Total:', 'campoal'); ?>
						</th>
						<th>
							<?php wc_cart_totals_order_total_html(); ?>
						</th>
					</tr>
				</tfoot>
				
				<?php do_action( 'woocommerce_cart_totals_after_order_total' ); ?>
		</tbody>
	</table><!--end of table-->
</div>
<div class="row">
	<div class="col-md-4 col-md-offset-8 text-right text-center-xs">
		<?php do_action( 'woocommerce_proceed_to_checkout' ); ?>
	</div>
</div><!--end of row-->

<?php do_action( 'woocommerce_after_cart_totals' ); ?>