<?php
/**
 * Checkout billing information form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/form-billing.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.6.0
 * @global WC_Checkout $checkout
 */

defined( 'ABSPATH' ) || exit;
?>
<div class="ui form woocommerce-billing-fields">
	<?php if ( wc_ship_to_billing_address_only() && WC()->cart->needs_shipping() ) : ?>

		<h2 class="ui header"><?php esc_html_e( 'Billing &amp; Shipping', 'campoal' ); ?></h2>

	<?php else : ?>

		<h2 class="ui header"><?php esc_html_e( 'Billing details', 'campoal' ); ?></h2>

	<?php endif; ?>

	<?php do_action( 'woocommerce_before_checkout_billing_form', $checkout ); ?>

	<div class="woocommerce-billing-fields__field-wrapper ui grid">
		<?php
		$fields = $checkout->get_checkout_fields( 'billing' );

		$full_width_fields = array( 
			'billing_address_1', 
			'billing_address_2', 
			'shipping_address_1', 
			'shipping_address_2', 
			'billing_company', 
			'shipping_company',
			'billing_country',
			'shipping_country',
			'billing_email',
			'shipping_email' );

		foreach ( $fields as $key => $field ) {

			if ( in_array( $key, $full_width_fields ) ) {
				$field['class'][] = 'sixteen wide column ui large input';
			} else {
				$field['class'][] = 'eight wide column ui large input';
			}

			// $field['label_class'] = array( 'small font' );
			// $field['input_class'] = array( 'ui large input' );

			woocommerce_form_field( $key, $field, $checkout->get_value( $key ) );
		}
		?>
	</div>

	<div class="ui hidden divider"></div>

	<?php do_action( 'woocommerce_after_checkout_billing_form', $checkout ); ?>
</div>

<?php if ( ! is_user_logged_in() && $checkout->is_registration_enabled() ) : ?>
	<div class="woocommerce-account-fields ui grid">
		<?php if ( ! $checkout->is_registration_required() ) : ?>

			<p class="form-row form-row-wide create-account">
				<div class="ui checkbox">
					<label class="woocommerce-form__label woocommerce-form__label-for-checkbox checkbox">
					<?php esc_html_e( 'Create an account?', 'campoal' ); ?>
					</label>
					<input class="woocommerce-form__input woocommerce-form__input-checkbox input-checkbox" id="createaccount" <?php checked( ( true === $checkout->get_value( 'createaccount' ) || ( true === apply_filters( 'woocommerce_create_account_default_checked', false ) ) ), true ); ?> type="checkbox" name="createaccount" value="1" /> 
				</div>
			</p>

			<div class="ui hidden divider"></div>

		<?php endif; ?>

		<?php do_action( 'woocommerce_before_checkout_registration_form', $checkout ); ?>

		<?php if ( $checkout->get_checkout_fields( 'account' ) ) : ?>

			<div class="create-account">
				<?php foreach ( $checkout->get_checkout_fields( 'account' ) as $key => $field ) : ?>

					<?php 
						$field['class'][]     = 'ui large input';
						// $field['label_class'] = array( 'small font' );
						// $field['input_class'] = array( 'ui large input' );
					?>

					<?php woocommerce_form_field( $key, $field, $checkout->get_value( $key ) ); ?>
				<?php endforeach; ?>
				<div class="clear"></div>
			</div>

		<?php endif; ?>

		<?php do_action( 'woocommerce_after_checkout_registration_form', $checkout ); ?>
	</div>
<?php endif; ?>

<div class="ui hidden divider"></div>
