<?php
/**
 * Checkout Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/form-checkout.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} ?>
<?php if (is_page_template('fullwidth.php') || is_page_template('container.php')) : ?>
<div class="wrapper<?php echo esc_attr(is_page_template('fullwidth.php') ? ' read' : '') ?> checkout">
	<div class="ui container">
		<h1 class="checkout-page-title"><?php echo get_the_title() ?></h1> 
<?php endif; ?>
		<?php 
		do_action( 'woocommerce_before_checkout_form', $checkout );

		// If checkout registration is disabled and not logged in, the user cannot checkout.
		if ( ! $checkout->is_registration_enabled() && $checkout->is_registration_required() && ! is_user_logged_in() ) {
			echo esc_html( apply_filters( 'woocommerce_checkout_must_be_logged_in_message', __( 'You must be logged in to checkout.', 'campoal' ) ) );
			return;
		}
		?>

		<form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">
			<div class="ui grid">
				<div class="sixteen wide mobile sixteen wide tablet <?php echo esc_attr(is_page_template('fullwidth.php') || is_page_template('container.php') || !is_active_sidebar('main-widget-area') ? 'eight' : 'sixteen') ?> wide computer column">
					<?php if ( $checkout->get_checkout_fields() ) : ?>

						<?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

						<?php do_action( 'woocommerce_checkout_billing' ); ?>

						<?php do_action( 'woocommerce_checkout_shipping' ); ?>
						
						<?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

					<?php endif; ?>
				</div>
				<div class="sixteen wide mobile sixteen wide tablet <?php echo esc_attr(is_page_template('fullwidth.php') || is_page_template('container.php') || !is_active_sidebar('main-widget-area') ? 'eight' : 'sixteen') ?> wide computer column">
					<?php do_action( 'woocommerce_checkout_before_order_review_heading' ); ?>
					
					<h2 class="ui header" id="order_review_heading"><?php esc_html_e( 'Your order', 'campoal' ); ?></h2>
					<div class="ui secondary padded segment">
						<?php do_action( 'woocommerce_checkout_before_order_review' ); ?>

						<div id="order_review" class="woocommerce-checkout-review-order">
							<?php do_action( 'woocommerce_checkout_order_review' ); ?>
						</div>

						<?php do_action( 'woocommerce_checkout_after_order_review' ); ?>
					</div>
				</div>
			</div>
		</form>

		<?php do_action( 'woocommerce_after_checkout_form', $checkout ); ?>

		<div class="ui hidden section divider"></div>
<?php if (is_page_template('fullwidth.php') || is_page_template('container.php')) : ?>
	</div>
</div>
<?php endif; ?>