<?php
/**
 * Login form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     7.0.1
 */

 if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( is_user_logged_in() ) {
	return;
}

?>
<form class="ui large form ui secondary segment woocommerce-form woocommerce-form-login login" method="post" <?php echo esc_attr( $hidden ) ? 'style="display:none;"' : ''; ?>>

	<?php do_action( 'woocommerce_login_form_start' ); ?>

	<?php echo wp_kses_post( $message ? wpautop( wptexturize( $message ) ) : ''); // @codingStandardsIgnoreLine ?>

	<div class="two fields">
		<div class="field required">
			<label for="username"><?php esc_html_e( 'Username or email', 'campoal' ); ?></label>
			<input type="text" class="input-text" name="username" id="username" autocomplete="username" />
		</div>
		<div class="field required">
			<label for="password"><?php esc_html_e( 'Password', 'campoal' ); ?></label>
			<input class="input-text" type="password" name="password" id="password" autocomplete="current-password" />
		</div>
	</div>
	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form' ); ?>

	<div class="field">
		<div class="ui checkbox">
			<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" />
			<label class="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme"><?php esc_html_e( 'Remember me', 'campoal' ); ?></label>
		</div>
	</div>
	<div class="clear"></div>
	<div class="field">
		<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
		<input type="hidden" name="redirect" value="<?php echo esc_url( $redirect ); ?>" />
		<button type="submit" class="ui primary large button woocommerce-button button woocommerce-form-login__submit<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="login" value="<?php esc_attr_e( 'Login', 'campoal' ); ?>"><?php esc_html_e( 'Login', 'campoal' ); ?></button>
	</div>
	<div class="clear"></div>
	<div class="ui hidden divider"></div>
	<p class="field lost_password">
		<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'campoal' ); ?></a>
	</p>

	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form_end' ); ?>

</form>
