<?php
/**
 * Login Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.0.1
 */

 if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

do_action( 'woocommerce_before_customer_login_form' ); ?>

<div class="wrapper login">
	<div class="ui container">
		<div class="ui centered grid">
			<div class="sixteen wide mobile eleven wide tablet eight wide computer column">
				<div class="ui secondary big menu woocommerce-login-tab" id="woocommerce-login-tab">
					<div class="right menu">
						<a class="active item" data-tab="login">Login</a>
						<?php if ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) : ?>
						<a class="item" data-tab="register">Register</a>
						<?php endif; ?>
					</div>
				</div>

				<div class="ui active tab padded raised segment" data-tab="login">
					<h2 class="ui header"><?php esc_html_e( 'Login', 'campoal' ); ?></h2>
					<div class="ui hidden divider"></div>
					<form class="ui large form" method="post">

						<?php do_action( 'woocommerce_login_form_start' ); ?>

						<div class="field required">
							<label for="username"><?php esc_html_e( 'Username or email address', 'campoal' ); ?></label>
							<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="username" autocomplete="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
						</div>

						<div class="field required">
							<label for="password"><?php esc_html_e( 'Password', 'campoal' ); ?></label>
							<input class="woocommerce-Input woocommerce-Input--text input-text" type="password" name="password" id="password" autocomplete="current-password" />
						</div>

						<?php do_action( 'woocommerce_login_form' ); ?>

						<div class="field">
							<div class="ui checkbox">
								<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" />
								<label class="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme"><?php esc_html_e( 'Remember me', 'campoal' ); ?></label>
							</div>
						</div>
						<div class="field">
							<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
							<button type="submit" class="ui primary large button woocommerce-button button woocommerce-form-login__submit<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="login" value="<?php esc_attr_e( 'Log in', 'campoal' ); ?>"><?php esc_html_e( 'Log in', 'campoal' ); ?></button>
						</div>

						<div class="field woocommerce-LostPassword lost_password">
							<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'campoal' ); ?></a>
						</div>

						<?php do_action( 'woocommerce_login_form_end' ); ?>

					</form>
				</div>

				<?php if ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) : ?>
					<div class="ui tab padded raised segment" data-tab="register">
						<h2 class="ui header"><?php esc_html_e( 'Register', 'campoal' ); ?></h2>
						<div class="ui hidden divider"></div>
						<form method="post" class="ui large form" <?php do_action( 'woocommerce_register_form_tag' ); ?> >

							<?php do_action( 'woocommerce_register_form_start' ); ?>

							<?php if ( 'no' === get_option( 'woocommerce_registration_generate_username' ) ) : ?>

								<div class="field required">
									<label for="reg_username"><?php esc_html_e( 'Username', 'campoal' ); ?></label>
									<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="reg_username" autocomplete="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
								</div>

							<?php endif; ?>

							<div class="field required">
								<label for="reg_email"><?php esc_html_e( 'Email address', 'campoal' ); ?></label>
								<input type="email" class="woocommerce-Input woocommerce-Input--text input-text" name="email" id="reg_email" autocomplete="email" value="<?php echo ( ! empty( $_POST['email'] ) ) ? esc_attr( wp_unslash( $_POST['email'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
							</div>

							<?php if ( 'no' === get_option( 'woocommerce_registration_generate_password' ) ) : ?>

								<div class="field required">
									<label for="reg_password"><?php esc_html_e( 'Password', 'campoal' ); ?></label>
									<input type="password" class="woocommerce-Input woocommerce-Input--text input-text" name="password" id="reg_password" autocomplete="new-password" />
								</div>

							<?php else : ?>

								<div class="field"><?php esc_html_e( 'A link to set a new password will be sent to your email address.', 'campoal' ); ?></p>

							<?php endif; ?>

							<div class="ui info message">
								<?php do_action( 'woocommerce_register_form' ); ?>
							</div>

							<div class="field woocommerce-form-row form-row">
								<?php wp_nonce_field( 'woocommerce-register', 'woocommerce-register-nonce' ); ?>
								<button type="submit" class="ui primary large button woocommerce-Button woocommerce-button button<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?> woocommerce-form-register__submit" name="register" value="<?php esc_attr_e( 'Register', 'campoal' ); ?>"><?php esc_html_e( 'Register', 'campoal' ); ?></button>
							</div>

							<?php do_action( 'woocommerce_register_form_end' ); ?>

						</form>
					</div>

				<?php endif; ?>
			</div>
		</div>
	</div>
</div>
<?php do_action( 'woocommerce_after_customer_login_form' ); ?>
