<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 4.3.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews" class="woocommerce-Reviews">
	<div class="ui grid">
		<div class="sixteen wide mobile sixteen wide tablet nine wide computer column" id="content<?php echo esc_attr($product->get_id()) ?>">
			<?php
			$count = $product->get_review_count();
			if ( $count && wc_review_ratings_enabled() ) { ?>
				<h2 class="ui large header woocommerce-Reviews-title">
					<?php
						/* translators: 1: reviews count 2: product name */
						$reviews_title = sprintf( esc_html( _n( '%1$s review for %2$s', '%1$s reviews for %2$s', $count, 'campoal' ) ), esc_html( $count ), '<span>' . get_the_title() . '</span>' );
						echo apply_filters( 'woocommerce_reviews_title', $reviews_title, $count, $product ); // WPCS: XSS ok. ?>
				</h2>
			<?php } ?>

			<?php if ( have_comments() ) : ?>
				<ul class="ui large comments commentlist">
					<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
				</ul>

				<?php
				if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
					echo '<nav class="woocommerce-pagination">';
					paginate_comments_links(
						apply_filters(
							'woocommerce_comment_pagination_args',
							array(
								'prev_text' => is_rtl() ? '&rarr;' : '&larr;',
								'next_text' => is_rtl() ? '&larr;' : '&rarr;',
								'type'      => 'list',
							)
						)
					);
					echo '</nav>';
				endif;
				?>
			<?php else : ?>
				<?php // display not found post notice
                conikal_not_found_post(sprintf( esc_html__('No reviews for ”%s”', 'campoal'), get_the_title() ), __("We're sorry, but no there are reviews on this product.", 'campoal')); ?>
			<?php endif; ?>
		</div>
		<div class="sixteen wide mobile sixteen wide tablet seven wide computer column">
			<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>
				<div class="ui sticky review-form" id="review-form" data-id="<?php echo esc_attr($product->get_id()) ?>">
					<div class="ui padded raised segment review-form-wrapper" id="review_form_wrapper">
						<div class="ui large form" id="review_form">
							<?php
							$commenter    = wp_get_current_commenter();
							$req        = get_option( 'require_name_email' );
							$aria_req   = ( $req ? " aria-required='true'" : '' );
							$comment_form = array(
								'class_form'            => 'ui large form',
								/* translators: %s is product title */
								'title_reply'         => have_comments() ? esc_html__( 'Add a review', 'campoal' ) : sprintf( esc_html__( 'Be the first to review &ldquo;%s&rdquo;', 'campoal' ), get_the_title() ),
								/* translators: %s is product title */
								'title_reply_to'      => esc_html__( 'Leave a Reply to %s', 'campoal' ),
								'title_reply_before'  => '<div id="reply-title" class="ui header comment-reply-title">',
								'title_reply_after'   => '</div>',
								'comment_notes_after' => '',
								'label_submit'        => esc_html__( 'Submit Review', 'campoal' ),
								'logged_in_as'        => '',
								'comment_field'       => '',
								'class_submit'        => 'field',
								'submit_button'       => '<input name="%1$s" type="submit" id="%2$s" class="%3$s ui primary large submit button" value="%4$s" />'
							);

							$name_email_required = (bool) get_option( 'require_name_email', 1 );
							$fields              = array(
								'author' => array(
									'label'    => __( 'Name', 'campoal' ),
									'type'     => 'text',
									'value'    => $commenter['comment_author'],
									'required' => $name_email_required,
								),
								'email'  => array(
									'label'    => __( 'Email', 'campoal' ),
									'type'     => 'email',
									'value'    => $commenter['comment_author_email'],
									'required' => $name_email_required,
								),
							);

							$comment_form['fields'] = array();

							foreach ( $fields as $key => $field ) {
								$field_html  = '<div class="field comment-form-' . esc_attr( $key ) . ($field['required'] ? ' required' : '') . '">';
								$field_html .= '<label>' . esc_html( $field['label'] );

								$field_html .= '</label><input id="' . esc_attr( $key ) . '" name="' . esc_attr( $key ) . '" type="' . esc_attr( $field['type'] ) . '" value="' . esc_attr( $field['value'] ) . '" size="30" ' . ( $field['required'] ? 'required' : '' ) . ' /></div>';

								$comment_form['fields'][ $key ] = $field_html;
							}

							$account_page_url = wc_get_page_permalink( 'myaccount' );
							if ( $account_page_url ) {
								/* translators: %s opening and closing link tags respectively */
								$comment_form['must_log_in'] = '<div class="field must-log-in">' . sprintf( esc_html__( 'You must be %1$slogged in%2$s to post a review.', 'campoal' ), '<a href="' . esc_url( $account_page_url ) . '">', '</a>' ) . '</div>';
							}

							if ( get_option( 'show_comments_cookies_opt_in' ) ) {
								$comment_form['fields']['cookies']   = '<div class="comment-form-cookies field"><div class="ui checkbox"><input type="checkbox" tabindex="0" class="hidden" id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" value="yes"' . (empty( $commenter['comment_author_email'] ) ? '' : ' checked=&quot;checked&quot;') . 
								'><label>' . 
								esc_html__('Save my name for the next time I comment.', 'campoal') . 
								'</label></div></div>';
							}

							if ( wc_review_ratings_enabled() ) {
								$comment_form['comment_field'] = '<div class="field comment-form-rating' . (wc_review_ratings_required() ? ' required' : '') . '"><label>' . esc_html__( 'Your rating', 'campoal' ) . '</label><select name="rating" id="rating" required>
									<option value="">' . esc_html__( 'Rate&hellip;', 'campoal' ) . '</option>
									<option value="5">' . esc_html__( 'Perfect', 'campoal' ) . '</option>
									<option value="4">' . esc_html__( 'Good', 'campoal' ) . '</option>
									<option value="3">' . esc_html__( 'Average', 'campoal' ) . '</option>
									<option value="2">' . esc_html__( 'Not that bad', 'campoal' ) . '</option>
									<option value="1">' . esc_html__( 'Very poor', 'campoal' ) . '</option>
								</select></div>';
							}

							$comment_form['comment_field'] .= '<div class="field required comment-form-comment"><label>' . esc_html__( 'Your review', 'campoal' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8" required></textarea></div>';

							comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
							?>
						</div>
					</div>
				<?php else : ?>
					<p class="woocommerce-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'campoal' ); ?></p>
				<?php endif; ?>

				<div class="clear"></div>
			</div>
		</div>
	</div>
</div>
